<!-- Auto-generated by scripts/skill_generator.py. Do not edit manually. -->
<!-- Regenerate with: just skills -->

# Builder Inventory

**132 builders** across the following modules:

## agent module (2 builders)

- **Agent** — `google.adk.agents.llm_agent.LlmAgent` (24 fields, 33 extras)
- **BaseAgent** — `google.adk.agents.base_agent.BaseAgent` (4 fields, 1 extras)

## config module (38 builders)

- **AgentConfig** — `google.adk.agents.agent_config.AgentConfig` (0 fields, 0 extras)
- **AgentRefConfig** — `google.adk.agents.common_configs.AgentRefConfig` (2 fields, 0 extras)
- **AgentSimulatorConfig** — `google.adk.tools.agent_simulator.agent_simulator_config.AgentSimulatorConfig` (5 fields, 1 extras)
- **AgentToolConfig** — `google.adk.tools.agent_tool.AgentToolConfig` (2 fields, 0 extras)
- **ArgumentConfig** — `google.adk.agents.common_configs.ArgumentConfig` (1 fields, 0 extras)
- **AudioCacheConfig** — `google.adk.flows.llm_flows.audio_cache_manager.AudioCacheConfig` (0 fields, 0 extras)
- **BaseAgentConfig** — `google.adk.agents.base_agent_config.BaseAgentConfig` (5 fields, 3 extras)
- **BaseGoogleCredentialsConfig** — `google.adk.tools._google_credentials.BaseGoogleCredentialsConfig` (5 fields, 0 extras)
- **BaseToolConfig** — `google.adk.tools.tool_configs.BaseToolConfig` (0 fields, 0 extras)
- **BigQueryCredentialsConfig** — `google.adk.tools.bigquery.bigquery_credentials.BigQueryCredentialsConfig` (5 fields, 0 extras)
- **BigQueryLoggerConfig** — `google.adk.plugins.bigquery_agent_analytics_plugin.BigQueryLoggerConfig` (0 fields, 0 extras)
- **BigQueryToolConfig** — `google.adk.tools.bigquery.config.BigQueryToolConfig` (7 fields, 0 extras)
- **BigtableCredentialsConfig** — `google.adk.tools.bigtable.bigtable_credentials.BigtableCredentialsConfig` (5 fields, 0 extras)
- **CodeConfig** — `google.adk.agents.common_configs.CodeConfig` (1 fields, 1 extras)
- **ContextCacheConfig** — `google.adk.agents.context_cache_config.ContextCacheConfig` (3 fields, 0 extras)
- **DataAgentCredentialsConfig** — `google.adk.tools.data_agent.credentials.DataAgentCredentialsConfig` (5 fields, 0 extras)
- **DataAgentToolConfig** — `google.adk.tools.data_agent.config.DataAgentToolConfig` (1 fields, 0 extras)
- **EventsCompactionConfig** — `google.adk.apps.app.EventsCompactionConfig` (3 fields, 0 extras)
- **ExampleToolConfig** — `google.adk.tools.example_tool.ExampleToolConfig` (0 fields, 0 extras)
- **FeatureConfig** — `google.adk.features._feature_registry.FeatureConfig` (0 fields, 0 extras)
- **GetSessionConfig** — `google.adk.sessions.base_session_service.GetSessionConfig` (2 fields, 0 extras)
- **InjectionConfig** — `google.adk.tools.agent_simulator.agent_simulator_config.InjectionConfig` (6 fields, 0 extras)
- **LlmAgentConfig** — `google.adk.agents.llm_agent_config.LlmAgentConfig` (20 fields, 8 extras)
- **LoopAgentConfig** — `google.adk.agents.loop_agent_config.LoopAgentConfig` (6 fields, 3 extras)
- **McpToolsetConfig** — `google.adk.tools.mcp_tool.mcp_toolset.McpToolsetConfig` (9 fields, 0 extras)
- **ParallelAgentConfig** — `google.adk.agents.parallel_agent_config.ParallelAgentConfig` (5 fields, 3 extras)
- **PubSubCredentialsConfig** — `google.adk.tools.pubsub.pubsub_credentials.PubSubCredentialsConfig` (5 fields, 0 extras)
- **PubSubToolConfig** — `google.adk.tools.pubsub.config.PubSubToolConfig` (1 fields, 0 extras)
- **ResumabilityConfig** — `google.adk.apps.app.ResumabilityConfig` (1 fields, 0 extras)
- **RetryConfig** — `google.adk.plugins.bigquery_agent_analytics_plugin.RetryConfig` (0 fields, 0 extras)
- **RunConfig** — `google.adk.agents.run_config.RunConfig` (17 fields, 0 extras)
- **SequentialAgentConfig** — `google.adk.agents.sequential_agent_config.SequentialAgentConfig` (5 fields, 3 extras)
- **SimplePromptOptimizerConfig** — `google.adk.optimization.simple_prompt_optimizer.SimplePromptOptimizerConfig` (4 fields, 0 extras)
- **SpannerCredentialsConfig** — `google.adk.tools.spanner.spanner_credentials.SpannerCredentialsConfig` (5 fields, 0 extras)
- **ToolArgsConfig** — `google.adk.tools.tool_configs.ToolArgsConfig` (0 fields, 0 extras)
- **ToolConfig** — `google.adk.tools.tool_configs.ToolConfig` (1 fields, 0 extras)
- **ToolSimulationConfig** — `google.adk.tools.agent_simulator.agent_simulator_config.ToolSimulationConfig` (2 fields, 1 extras)
- **ToolThreadPoolConfig** — `google.adk.agents.run_config.ToolThreadPoolConfig` (1 fields, 0 extras)

## executor module (5 builders)

- **AgentEngineSandboxCodeExecutor** — `google.adk.code_executors.agent_engine_sandbox_code_executor.AgentEngineSandboxCodeExecutor` (6 fields, 1 extras)
- **BaseCodeExecutor** — `google.adk.code_executors.base_code_executor.BaseCodeExecutor` (5 fields, 1 extras)
- **BuiltInCodeExecutor** — `google.adk.code_executors.built_in_code_executor.BuiltInCodeExecutor` (5 fields, 1 extras)
- **UnsafeLocalCodeExecutor** — `google.adk.code_executors.unsafe_local_code_executor.UnsafeLocalCodeExecutor` (5 fields, 1 extras)
- **VertexAiCodeExecutor** — `google.adk.code_executors.vertex_ai_code_executor.VertexAiCodeExecutor` (6 fields, 0 extras)

## planner module (3 builders)

- **BasePlanner** — `google.adk.planners.base_planner.BasePlanner` (0 fields, 0 extras)
- **BuiltInPlanner** — `google.adk.planners.built_in_planner.BuiltInPlanner` (0 fields, 0 extras)
- **PlanReActPlanner** — `google.adk.planners.plan_re_act_planner.PlanReActPlanner` (0 fields, 0 extras)

## plugin module (12 builders)

- **AgentSimulatorPlugin** — `google.adk.tools.agent_simulator.agent_simulator_plugin.AgentSimulatorPlugin` (0 fields, 0 extras)
- **BasePlugin** — `google.adk.plugins.base_plugin.BasePlugin` (0 fields, 0 extras)
- **BigQueryAgentAnalyticsPlugin** — `google.adk.plugins.bigquery_agent_analytics_plugin.BigQueryAgentAnalyticsPlugin` (0 fields, 0 extras)
- **ContextFilterPlugin** — `google.adk.plugins.context_filter_plugin.ContextFilterPlugin` (0 fields, 0 extras)
- **DebugLoggingPlugin** — `google.adk.plugins.debug_logging_plugin.DebugLoggingPlugin` (0 fields, 0 extras)
- **GlobalInstructionPlugin** — `google.adk.plugins.global_instruction_plugin.GlobalInstructionPlugin` (0 fields, 0 extras)
- **LoggingPlugin** — `google.adk.plugins.logging_plugin.LoggingPlugin` (0 fields, 0 extras)
- **MultimodalToolResultsPlugin** — `google.adk.plugins.multimodal_tool_results_plugin.MultimodalToolResultsPlugin` (0 fields, 0 extras)
- **RecordingsPlugin** — `google.adk.cli.plugins.recordings_plugin.RecordingsPlugin` (0 fields, 0 extras)
- **ReflectAndRetryToolPlugin** — `google.adk.plugins.reflect_retry_tool_plugin.ReflectAndRetryToolPlugin` (0 fields, 0 extras)
- **ReplayPlugin** — `google.adk.cli.plugins.replay_plugin.ReplayPlugin` (0 fields, 0 extras)
- **SaveFilesAsArtifactsPlugin** — `google.adk.plugins.save_files_as_artifacts_plugin.SaveFilesAsArtifactsPlugin` (0 fields, 0 extras)

## runtime module (3 builders)

- **App** — `google.adk.apps.app.App` (4 fields, 1 extras)
- **InMemoryRunner** — `google.adk.runners.InMemoryRunner` (0 fields, 0 extras)
- **Runner** — `google.adk.runners.Runner` (0 fields, 0 extras)

## service module (15 builders)

- **BaseArtifactService** — `google.adk.artifacts.base_artifact_service.BaseArtifactService` (0 fields, 0 extras)
- **BaseMemoryService** — `google.adk.memory.base_memory_service.BaseMemoryService` (0 fields, 0 extras)
- **BaseSessionService** — `google.adk.sessions.base_session_service.BaseSessionService` (0 fields, 0 extras)
- **DatabaseSessionService** — `google.adk.sessions.database_session_service.DatabaseSessionService` (0 fields, 0 extras)
- **FileArtifactService** — `google.adk.artifacts.file_artifact_service.FileArtifactService` (0 fields, 0 extras)
- **ForwardingArtifactService** — `google.adk.tools._forwarding_artifact_service.ForwardingArtifactService` (0 fields, 0 extras)
- **GcsArtifactService** — `google.adk.artifacts.gcs_artifact_service.GcsArtifactService` (0 fields, 0 extras)
- **InMemoryArtifactService** — `google.adk.artifacts.in_memory_artifact_service.InMemoryArtifactService` (1 fields, 0 extras)
- **InMemoryMemoryService** — `google.adk.memory.in_memory_memory_service.InMemoryMemoryService` (0 fields, 0 extras)
- **InMemorySessionService** — `google.adk.sessions.in_memory_session_service.InMemorySessionService` (0 fields, 0 extras)
- **PerAgentDatabaseSessionService** — `google.adk.cli.utils.local_storage.PerAgentDatabaseSessionService` (0 fields, 0 extras)
- **SqliteSessionService** — `google.adk.sessions.sqlite_session_service.SqliteSessionService` (0 fields, 0 extras)
- **VertexAiMemoryBankService** — `google.adk.memory.vertex_ai_memory_bank_service.VertexAiMemoryBankService` (0 fields, 0 extras)
- **VertexAiRagMemoryService** — `google.adk.memory.vertex_ai_rag_memory_service.VertexAiRagMemoryService` (0 fields, 0 extras)
- **VertexAiSessionService** — `google.adk.sessions.vertex_ai_session_service.VertexAiSessionService` (0 fields, 0 extras)

## tool module (51 builders)

- **APIHubToolset** — `google.adk.tools.apihub_tool.apihub_toolset.APIHubToolset` (0 fields, 0 extras)
- **ActiveStreamingTool** — `google.adk.agents.active_streaming_tool.ActiveStreamingTool` (2 fields, 0 extras)
- **AgentTool** — `google.adk.tools.agent_tool.AgentTool` (0 fields, 0 extras)
- **ApplicationIntegrationToolset** — `google.adk.tools.application_integration_tool.application_integration_toolset.ApplicationIntegrationToolset` (0 fields, 0 extras)
- **BaseAuthenticatedTool** — `google.adk.tools.base_authenticated_tool.BaseAuthenticatedTool` (0 fields, 0 extras)
- **BaseRetrievalTool** — `google.adk.tools.retrieval.base_retrieval_tool.BaseRetrievalTool` (0 fields, 0 extras)
- **BaseTool** — `google.adk.tools.base_tool.BaseTool` (0 fields, 0 extras)
- **BaseToolset** — `google.adk.tools.base_toolset.BaseToolset` (0 fields, 0 extras)
- **BigQueryToolset** — `google.adk.tools.bigquery.bigquery_toolset.BigQueryToolset` (0 fields, 0 extras)
- **BigtableToolset** — `google.adk.tools.bigtable.bigtable_toolset.BigtableToolset` (0 fields, 0 extras)
- **CalendarToolset** — `google.adk.tools.google_api_tool.google_api_toolsets.CalendarToolset` (0 fields, 0 extras)
- **ComputerUseTool** — `google.adk.tools.computer_use.computer_use_tool.ComputerUseTool` (0 fields, 0 extras)
- **ComputerUseToolset** — `google.adk.tools.computer_use.computer_use_toolset.ComputerUseToolset` (0 fields, 0 extras)
- **DataAgentToolset** — `google.adk.tools.data_agent.data_agent_toolset.DataAgentToolset` (0 fields, 0 extras)
- **DiscoveryEngineSearchTool** — `google.adk.tools.discovery_engine_search_tool.DiscoveryEngineSearchTool` (0 fields, 0 extras)
- **DocsToolset** — `google.adk.tools.google_api_tool.google_api_toolsets.DocsToolset` (0 fields, 0 extras)
- **EnterpriseWebSearchTool** — `google.adk.tools.enterprise_search_tool.EnterpriseWebSearchTool` (0 fields, 0 extras)
- **ExampleTool** — `google.adk.tools.example_tool.ExampleTool` (0 fields, 0 extras)
- **FunctionTool** — `google.adk.tools.function_tool.FunctionTool` (0 fields, 0 extras)
- **GmailToolset** — `google.adk.tools.google_api_tool.google_api_toolsets.GmailToolset` (0 fields, 0 extras)
- **GoogleApiTool** — `google.adk.tools.google_api_tool.google_api_tool.GoogleApiTool` (0 fields, 0 extras)
- **GoogleApiToolset** — `google.adk.tools.google_api_tool.google_api_toolset.GoogleApiToolset` (0 fields, 0 extras)
- **GoogleMapsGroundingTool** — `google.adk.tools.google_maps_grounding_tool.GoogleMapsGroundingTool` (0 fields, 0 extras)
- **GoogleSearchAgentTool** — `google.adk.tools.google_search_agent_tool.GoogleSearchAgentTool` (0 fields, 0 extras)
- **GoogleSearchTool** — `google.adk.tools.google_search_tool.GoogleSearchTool` (0 fields, 0 extras)
- **GoogleTool** — `google.adk.tools.google_tool.GoogleTool` (0 fields, 0 extras)
- **IntegrationConnectorTool** — `google.adk.tools.application_integration_tool.integration_connector_tool.IntegrationConnectorTool` (0 fields, 0 extras)
- **LoadArtifactsTool** — `google.adk.tools.load_artifacts_tool.LoadArtifactsTool` (0 fields, 0 extras)
- **LoadMcpResourceTool** — `google.adk.tools.load_mcp_resource_tool.LoadMcpResourceTool` (0 fields, 0 extras)
- **LoadMemoryTool** — `google.adk.tools.load_memory_tool.LoadMemoryTool` (0 fields, 0 extras)
- **LoadSkillResourceTool** — `google.adk.tools.skill_toolset.LoadSkillResourceTool` (0 fields, 0 extras)
- **LoadSkillTool** — `google.adk.tools.skill_toolset.LoadSkillTool` (0 fields, 0 extras)
- **LongRunningFunctionTool** — `google.adk.tools.long_running_tool.LongRunningFunctionTool` (0 fields, 0 extras)
- **MCPTool** — `google.adk.tools.mcp_tool.mcp_tool.MCPTool` (0 fields, 0 extras)
- **MCPToolset** — `google.adk.tools.mcp_tool.mcp_toolset.MCPToolset` (0 fields, 0 extras)
- **McpTool** — `google.adk.tools.mcp_tool.mcp_tool.McpTool` (0 fields, 0 extras)
- **McpToolset** — `google.adk.tools.mcp_tool.mcp_toolset.McpToolset` (0 fields, 0 extras)
- **OpenAPIToolset** — `google.adk.tools.openapi_tool.openapi_spec_parser.openapi_toolset.OpenAPIToolset` (0 fields, 0 extras)
- **PreloadMemoryTool** — `google.adk.tools.preload_memory_tool.PreloadMemoryTool` (0 fields, 0 extras)
- **PubSubToolset** — `google.adk.tools.pubsub.pubsub_toolset.PubSubToolset` (0 fields, 0 extras)
- **RestApiTool** — `google.adk.tools.openapi_tool.openapi_spec_parser.rest_api_tool.RestApiTool` (0 fields, 0 extras)
- **SetModelResponseTool** — `google.adk.tools.set_model_response_tool.SetModelResponseTool` (0 fields, 0 extras)
- **SheetsToolset** — `google.adk.tools.google_api_tool.google_api_toolsets.SheetsToolset` (0 fields, 0 extras)
- **SkillToolset** — `google.adk.tools.skill_toolset.SkillToolset` (0 fields, 0 extras)
- **SlidesToolset** — `google.adk.tools.google_api_tool.google_api_toolsets.SlidesToolset` (0 fields, 0 extras)
- **SpannerToolset** — `google.adk.tools.spanner.spanner_toolset.SpannerToolset` (0 fields, 0 extras)
- **ToolboxToolset** — `google.adk.tools.toolbox_toolset.ToolboxToolset` (0 fields, 0 extras)
- **TransferToAgentTool** — `google.adk.tools.transfer_to_agent_tool.TransferToAgentTool` (0 fields, 0 extras)
- **UrlContextTool** — `google.adk.tools.url_context_tool.UrlContextTool` (0 fields, 0 extras)
- **VertexAiSearchTool** — `google.adk.tools.vertex_ai_search_tool.VertexAiSearchTool` (0 fields, 0 extras)
- **YoutubeToolset** — `google.adk.tools.google_api_tool.google_api_toolsets.YoutubeToolset` (0 fields, 0 extras)

## workflow module (3 builders)

- **FanOut** — `google.adk.agents.parallel_agent.ParallelAgent` (4 fields, 3 extras)
- **Loop** — `google.adk.agents.loop_agent.LoopAgent` (5 fields, 3 extras)
- **Pipeline** — `google.adk.agents.sequential_agent.SequentialAgent` (4 fields, 3 extras)
